package Alien::PDFio;

use 5.006;
use strict;
use warnings;

our $VERSION = '0.02';

use File::ShareDir qw(dist_dir);
use File::Spec;

use parent 'Alien::Base';

sub incdir {
	my $class = shift;

	return File::Spec->catdir(
		dist_dir("Alien-PDFio"),
		"include"
	);
}

sub libdir {
	my $class = shift;

	return File::Spec->catdir(
		dist_dir("Alien-PDFio"),
		"lib"
	);
}

1;
__END__;

=head1 NAME

Alien::PDFio - Alien distribution for PDFio

=head1 VERSION

Version 0.02

=cut

=head1 SYNOPSIS

	use Alien::PDFio;
	
	my $incdir = Alien::PDFio->incdir();
	my $libdir = Alien::PDFio->libdir();

=head1 AUTHOR

LNATION, C<< <email at lnation.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-alien-pdfio at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Alien-PDFio>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Alien::PDFio

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Alien-PDFio>

=item * Search CPAN

L<https://metacpan.org/release/Alien-PDFio>

=back

=head1 ACKNOWLEDGEMENTS

=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2025 by LNATION.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)


=cut

1; # End of Alien::PDFio
